@@ -141,7 +141,7 @@ enum {
  * Print a detailed usage message to the provided output stream.
  */
 static void printUsage(ostream& out) {
-	out << "Centrifuge version " << string(CENTRIFUGE_VERSION).c_str() << " by Daehwan Kim (infphilo@gmail.com, http://www.ccb.jhu.edu/people/infphilo)" << endl;
+	out << "Centrifuge version " << string(CENTRIFUGE_VERSION).c_str() << " by the Centrifuge developer team (centrifuge.metagenomics@gmail.com)" << endl;
 	string tool_name = "centrifuge-build-bin";
 	if(wrapper == "basic-0") {
 		tool_name = "centrifuge-build";
@@ -154,8 +154,8 @@ static void printUsage(ostream& out) {
         << "    -c                      reference sequences given on cmd line (as" << endl
         << "                            <reference_in>)" << endl;
     if(wrapper == "basic-0") {
-        out << "    --large-index           force generated index to be 'large', even if ref" << endl
-		<< "                            has fewer than 4 billion nucleotides" << endl;
+        //out << "    --large-index           force generated index to be 'large', even if ref" << endl
+	//	<< "                            has fewer than 4 billion nucleotides" << endl;
 	}
     out << "    -a/--noauto             disable automatic -p/--bmax/--dcv memory-fitting" << endl
 	    << "    --bmax <int>            max bucket sz for blockwise suffix-array builder" << endl
@@ -164,7 +164,7 @@ static void printUsage(ostream& out) {
 	    << "    --nodc                  disable diff-cover (algorithm becomes quadratic)" << endl
 	    << "    -r/--noref              don't build .3/.4.bt2 (packed reference) portion" << endl
 	    << "    -3/--justref            just build .3/.4.bt2 (packed reference) portion" << endl
-	    << "    -o/--offrate <int>      SA is sampled every 2^offRate BWT chars (default: 5)" << endl
+	    << "    -o/--offrate <int>      SA is sampled every 2^offRate BWT chars (default: 4)" << endl
 	    << "    -t/--ftabchars <int>    # of chars consumed in initial lookup (default: 10)" << endl
         << "    --conversion-table <file name>  a table that converts any id to a taxonomy id" << endl
         << "    --taxonomy-tree    <file name>  taxonomy tree" << endl
