@@ -41,7 +41,7 @@ struct HitCount {
     bool     leaf;
     uint32_t num_leaves;
     
-    uint8_t rank;
+    uint8_t _rank;  // there are compilation error w/ g++ v7.2.0 on OSX when naming the member 'rank' instead of '_rank' 
     EList<uint64_t> path;
     
     void reset() {
@@ -50,7 +50,7 @@ struct HitCount {
         summedHitLen = 0.0;
         summedHitLens[0][0] = summedHitLens[0][1] = summedHitLens[1][0] = summedHitLens[1][1] = 0.0;
         readPositions.clear();
-        rank = 0;
+        _rank = 0;
         path.clear();
         leaf = true;
         num_leaves = 1;
@@ -77,7 +77,7 @@ struct HitCount {
         readPositions = o.readPositions;
         leaf = o.leaf;
         num_leaves = o.num_leaves;
-        rank = o.rank;
+        _rank = o._rank;
         path = o.path;
         
         return *this;
@@ -296,7 +296,7 @@ public:
                     
                     // the maximum number of hits per read is maxGenomeHitSize (change with parameter -k)
                     size_t nHitsToConsider = coords.size();
-                    if(coords.size() > rp.ihits) {
+                    if((THitInt)coords.size() > rp.ihits) {
                         continue;
                     }
 
@@ -337,7 +337,7 @@ public:
                         uint64_t uniqueID = coord_ids[k].first;
                         uint64_t taxID = coord_ids[k].second;
                         if(_excluded_taxIDs.find(taxID) != _excluded_taxIDs.end())
-                            break;
+                            continue ;
                         // add hit to genus map and get new index in the map
                         size_t idx = addHitToHitMap(
                                                     ebwtFw,
@@ -408,7 +408,7 @@ public:
             // Remove secondary hits
             for(int i = 0; i < (int)_hitMap.size(); i++) {
                 if(_hitMap[i].score < best_score) {
-                    if(i + 1 < _hitMap.size()) {
+                    if(i + 1 < (int)_hitMap.size()) {
                         _hitMap[i] = _hitMap.back();
                     }
                     _hitMap.pop_back();
@@ -428,16 +428,16 @@ public:
             while(_hitMap.size() > (size_t)rp.khits) {
                 _hitTaxCount.clear();
                 for(size_t i = 0; i < _hitMap.size(); i++) {
-                    while(_hitMap[i].rank < rank) {
-                        if(_hitMap[i].rank + 1 >= _hitMap[i].path.size()) {
-                            _hitMap[i].rank = std::numeric_limits<uint8_t>::max();
+                    while(_hitMap[i]._rank < rank) {
+                        if(_hitMap[i]._rank + 1 >= _hitMap[i].path.size()) {
+                            _hitMap[i]._rank = std::numeric_limits<uint8_t>::max();
                             break;
                         }
-                        _hitMap[i].rank += 1;
-                        _hitMap[i].taxID = _hitMap[i].path[_hitMap[i].rank];
+                        _hitMap[i]._rank += 1;
+                        _hitMap[i].taxID = _hitMap[i].path[_hitMap[i]._rank];
                         _hitMap[i].leaf = false;
                     }
-                    if(_hitMap[i].rank > rank) continue;
+                    if(_hitMap[i]._rank > rank) continue;
                     
                     uint64_t parent_taxID = (rank + 1 >= _hitMap[i].path.size() ? 1 : _hitMap[i].path[rank + 1]);
                     // Traverse up the tree more until we get non-zero taxID.
@@ -470,12 +470,12 @@ public:
                     uint64_t parent_taxID = _hitTaxCount[j].second;
                     int64_t max_score = 0;
                     for(size_t i = 0; i < _hitMap.size(); i++) {
-                        assert_geq(_hitMap[i].rank, rank);
-                        if(_hitMap[i].rank != rank) continue;
+                        assert_geq(_hitMap[i]._rank, rank);
+                        if(_hitMap[i]._rank != rank) continue;
                         uint64_t cur_parent_taxID = (rank + 1 >= _hitMap[i].path.size() ? 1 : _hitMap[i].path[rank + 1]);
                         if(parent_taxID == cur_parent_taxID) {
                             _hitMap[i].uniqueID = std::numeric_limits<uint64_t>::max();
-                            _hitMap[i].rank = rank + 1;
+                            _hitMap[i]._rank = rank + 1;
                             _hitMap[i].taxID = parent_taxID;
                             _hitMap[i].leaf = false;
                         }
@@ -508,7 +508,7 @@ public:
                     if(_hitMap.size() <= (size_t)rp.khits)
                         break;
                 }
-                rank++;
+                ++rank;
                 if(rank > _hitMap[0].path.size())
                     break;
             }
@@ -615,6 +615,16 @@ public:
         
         return true;
     }
+
+    void reportUnclassified( AlnSinkWrap<index_t>& sink )
+    {
+	    AlnRes rs ;
+	    EList<pair<uint32_t,uint32_t> > dummy ;
+	    dummy.push_back( make_pair( 0, 0 ) ) ;
+	    rs.init( 0, 0, string( "unclassified" ), 0, 0, 0, dummy, true ) ;
+	    sink.report( 0, &rs ) ;
+    }
+
 private:
     EList<string>                _refnames;
     EList<HitCount<index_t> >    _hitMap;
@@ -644,7 +654,9 @@ private:
         const Read& rd = *(this->_rds[rdi]);
 
         bool done[2] = {false, false};
+#ifdef LI_DEBUG
         size_t cur[2] = {0, 0} ;
+#endif
         
         index_t rdlen = rd.length();
         //const size_t maxDiff = (rdlen / 2 > 2 * _minHitLen) ? rdlen / 2 : (2 * _minHitLen);
@@ -673,7 +685,9 @@ private:
                 BWTHit<index_t>& lastHit = hit.getPartialHit(hit.offsetSize() - 1);
                 if(hit.done()) {
                     done[fwi] = true;
+#ifdef LI_DEBUG
                     cur[fwi] = rdlen;
+#endif
                     if(lastHit.len() >= _minHitLen) {
                         sum[fwi] += lastHit.len();
                         if(0) //lastHit.len() < 31 && rdlen > 31 && lastHit.size() == 1 )
@@ -703,8 +717,8 @@ private:
                     continue;
                 }
                 
-                cur[fwi] = hit.cur();
 #ifdef LI_DEBUG
+                cur[fwi] = hit.cur();
                 cout << fwi << ":" << lastHit.len() << " " << cur[fwi] << " ";
 #endif
                 if(lastHit.len() >= _minHitLen)
@@ -1026,7 +1040,7 @@ private:
 		    hitCount.readPositions.clear();
 		    hitCount.readPositions.push_back(make_pair(offset, length));
 		    hitCount.path = _tempPath;
-		    hitCount.rank = rank;
+		    hitCount._rank = rank;
 		    hitCount.taxID = taxID;
 	    }
 
@@ -1035,14 +1049,6 @@ private:
 	    return idx;
     }
 
-    void reportUnclassified( AlnSinkWrap<index_t>& sink )
-    {
-	    AlnRes rs ;
-	    EList<pair<uint32_t,uint32_t> > dummy ;
-	    dummy.push_back( make_pair( 0, 0 ) ) ;
-	    rs.init( 0, 0, string( "unclassified" ), 0, 0, 0, dummy, true ) ;
-	    sink.report( 0, &rs ) ;
-    }
 
 
 
