@@ -172,8 +172,12 @@ void calcExhaustiveDC(T i, bool verbose = false, bool sanityCheck = false) {
 					assert_lt(d2, v);
 					assert_gt(d1, 0);
 					assert_gt(d2, 0);
-					if(!diffs[d1]) diffCnt++; diffs[d1] = true;
-					if(!diffs[d2]) diffCnt++; diffs[d2] = true;
+					if(!diffs[d1]) 
+						diffCnt++; 
+					diffs[d1] = true;
+					if(!diffs[d2]) 
+						diffCnt++; 
+					diffs[d2] = true;
 				}
 			}
 			// Do we observe all possible differences (except 0)
