@@ -2783,7 +2783,7 @@ public:
 
 	explicit EBitList(size_t isz, int cat = 0) : l_(isz, cat) { reset(); }
 	
-	explicit EBitList(int cat = 0) : l_(cat) { reset(); }
+	//explicit EBitList(int cat = 0) : l_(cat) { reset(); }
 
 	/**
 	 * Reset to empty state.
